internal

package
v3.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2026 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtendedPatternMatcher

func ExtendedPatternMatcher(pat string, mode pattern.Mode) (func(string) bool, error)

ExtendedPatternMatcher returns a regexp.Regexp.MatchString-like function to support !(pattern-list) extended patterns where possible. It can be used instead of pattern.Regexp for narrow use cases.

func TestMainSetup

func TestMainSetup()

TestMainSetup is used by the integration tests running shell scripts either via our interpreter or via real shells, to ensure a reasonably clean and consistent environment.

Types

This section is empty.

Jump to