Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtendedPatternMatcher ¶
ExtendedPatternMatcher returns a regexp.Regexp.MatchString-like function to support !(pattern-list) extended patterns where possible. It can be used instead of pattern.Regexp for narrow use cases.
func TestMainSetup ¶
func TestMainSetup()
TestMainSetup is used by the integration tests running shell scripts either via our interpreter or via real shells, to ensure a reasonably clean and consistent environment.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.